@@ -1,5 +1,5 @@
 anm.ls.reg<-function (X, Y, parameter = "slope",  
-    nmax=50, interval = 0.1,...) 
+    nmax=50, interval = 0.1, col = "red",...) 
 {
     lin.mod <- lm(Y ~ X)
     b0 <- summary(lin.mod)$coefficients[1]
@@ -32,19 +32,19 @@ anm.ls.reg<-function (X, Y, parameter = "slope",
                 abline(b0, b1, lwd = 1.4)
                 if(parameter == "intercept") abline(poss[i],b1, col="gray")
                 if(parameter == "slope") abline(b0,poss[i], col="gray")
-                segments(X, Y, X, fitted[,i],lty = 2, col = 2) 
+                segments(X, Y, X, fitted[,i],lty = 2, col = col) 
                 }
                 
                 if(i == length(poss)){
-                plot(X, Y)
+                plot(X, Y, xlab = expression(italic(X)), ylab=expression(italic(Y)))
                 abline(b0, b1, lwd = 1.4)
-                segments(X, Y, X, fitted(lin.mod),lty = 2, col = 2)
+                segments(X, Y, X, fitted(lin.mod),lty = 2, col = col)
                 }
                           
                 plot(poss, ss.res, ylab = "Residual sum of squares", xlab = 
                 ifelse(parameter == "intercept","Intercept estimate","Slope estimate"), type = "n") 
-                arrows(poss[i], ss.res[i], poss[i + 1], ss.res[i + 1], col = 2, length = 0.15, lwd = 1)
-                points(poss[1:i], ss.res[1:i], lty = 2, col = 2, lwd = 1, type = "l")
+                arrows(poss[i], ss.res[i], poss[i + 1], ss.res[i + 1], col = col, length = 0.15, lwd = 1)
+                points(poss[1:i], ss.res[1:i], lty = 2, col = col, lwd = 1, type = "l")
                   
                 if(i < length(poss)){
                 legend("topright", legend = bquote(paste("SS = ", .(ss.res[i]))), cex = 0.9, bty = "n")
