@@ -1,12 +1,16 @@
 book.menu <- function () 
 {
-    require(tcltk) || stop("tcltk support is absent")
+
     tclServiceMode(TRUE)
     tt <- tktoplevel()
-    tkwm.title(tt, "Foundational Statistics for Biologists")
+    tkwm.title(tt, "Foundational and Applied Statistics for Biologists using R")
     topMenu <- tkmenu(tt)
     tkconfigure(tt, menu = topMenu, width = 800, height = 150)
   
+#----------------------- Menu labels ---------------------#
+
+# Book menu
+
 	Ch1 <- tkmenu(topMenu, tearoff = FALSE)
 	Ch2 <- tkmenu(topMenu, tearoff = FALSE)
 	Ch3 <- tkmenu(topMenu, tearoff = FALSE)
@@ -18,24 +22,40 @@ book.menu <- function ()
 	Ch9 <- tkmenu(topMenu, tearoff = FALSE)
 	Ch10 <- tkmenu(topMenu, tearoff = FALSE)
 	Ch11 <- tkmenu(topMenu, tearoff = FALSE)
-	Biology <- tkmenu(topMenu, tearoff = FALSE)
-	questions2 <- tkmenu(topMenu, tearoff = FALSE)
+	
+# Biology menu
+
+  Biology <- tkmenu(topMenu, tearoff = FALSE)
+
+# Self test questions
+	
+  questions1 <- tkmenu(topMenu, tearoff = FALSE)
+  questions2 <- tkmenu(topMenu, tearoff = FALSE)
 	questions3 <- tkmenu(topMenu, tearoff = FALSE)
+	questions4 <- tkmenu(topMenu, tearoff = FALSE)
 	questions5 <- tkmenu(topMenu, tearoff = FALSE)
+	questions6 <- tkmenu(topMenu, tearoff = FALSE)
 	questions7 <- tkmenu(topMenu, tearoff = FALSE)
-  dists1 <- tkmenu(topMenu, tearoff = FALSE) # Ch 3 (Ch 4, Ch 5, Ch 6)
+	questions8 <- tkmenu(topMenu, tearoff = FALSE)
+	questions9 <- tkmenu(topMenu, tearoff = FALSE)
+	questions10 <- tkmenu(topMenu, tearoff = FALSE)
+	questions11 <- tkmenu(topMenu, tearoff = FALSE)
+	
+ dists1 <- tkmenu(topMenu, tearoff = FALSE) # Ch 3 (Ch 4, Ch 5, Ch 6)
+
+#------------------- Menu contents -----------------------#
 
 # Chapter 1
   
-	tkadd(Ch1, "command", label = "Accuracy and precision", command = substitute(see.accPrec.tck())) # Ch 1
-	tkadd(Ch1, "command", label = "Logic", command = substitute(see.logic())) # Ch 1
+  tkadd(Ch1, "cascade", label = "Self-test questions", menu = questions1) #Names question menus
+	   tkadd(questions1, "command", label = "Logic", command = substitute(see.logic())) # Ch 1 question
+  tkadd(Ch1, "command", label = "Accuracy and precision", command = substitute(see.accPrec.tck())) # Ch 1
 	tkadd(topMenu, "cascade", label = "Chapter 1", menu = Ch1) # Names Ch 1
 
 # Chapter 2
 
-	tkadd(questions2, "command", label = "Probability", command = substitute(selftest.prob.tck1())) # Ch 2 question
-	tkadd(Ch2, "cascade", label = "Self-test questions", menu = questions2) #Names question menus
-	
+  tkadd(Ch2, "cascade", label = "Self-test questions", menu = questions2) #Names question menus
+    	tkadd(questions2, "command", label = "Probability", command = substitute(selftest.prob.tck1())) # Ch 2 question
 	tkadd(Ch2, "command", label = "Bayesian analysis of discrete data", 
         command = substitute(print(Bayes.disc.tck()))) # Ch 2
 	tkadd(Ch2, "command", label = "Coin flips", command = substitute(anm.coin.tck())) # Ch 2
@@ -44,9 +64,9 @@ book.menu <- function ()
 	tkadd(topMenu, "cascade", label = "Chapter 2", menu = Ch2) # Names Ch 2
 
 # Chapter 3
-
-	tkadd(questions3, "command", label = "Pdfs", command = substitute(selftest.pdfs.tck1())) # Ch 3 question
-	tkadd(Ch3, "cascade", label = "Self-test questions", menu = questions3) #Names question menus
+  
+  tkadd(Ch3, "cascade", label = "Self-test questions", menu = questions3) #Names question menus
+	   tkadd(questions3, "command", label = "Pdfs", command = substitute(selftest.pdfs.tck1())) # Ch 3 question
 	tkadd(Ch3, "command", label = "Continuous pdf conceptualization", command = substitute(see.pdf.conc.tck())) # Ch 3 
 	tkadd(Ch3, "command", label = "Exponential power function", 
         command = substitute(see.exppower.tck())) # Ch 3
@@ -57,31 +77,40 @@ book.menu <- function ()
 	
 # Chapter 4
 
+  tkadd(Ch4, "cascade", label = "Self-test questions", menu = questions4) #Names question menus
 	tkadd(Ch4, "command", label = "Cognitive illusions", command = substitute(example(illusions))) # Ch 4
 	tkadd(Ch4, "command", label = "Least squares", command = substitute(anm.ls.tck())) # Ch 4
 	tkadd(Ch4, "command", label = "Log-likelihood", command = substitute(anm.loglik.tck())) # Ch 4
 	tkadd(Ch4, "command", label = "M-estimation", command = substitute(see.M())) # Ch 4	
-	
 	tkadd(topMenu, "cascade", label = "Chapter 4", menu = Ch4) # Names Ch 4
 
+    # Shaded Distributions
+
+    tkadd(dists1, "command", label = "Normal", command = substitute(shade.norm.tck()))  
+    tkadd(dists1, "command", label = "Binomial", command = substitute(shade.bin.tck()))
+    tkadd(dists1, "command", label = "Chi-square", command = substitute(shade.chi.tck()))
+    tkadd(dists1, "command", label = "F", command = substitute(shade.F.tck()))
+    tkadd(dists1, "command", label = "Poisson", command = substitute(shade.poi.tck()))
+    tkadd(dists1, "command", label = "t", command = substitute(shade.t.tck()))
+
+
 # Chapter 5
 	tkadd(Ch5, "cascade", label = "Self-test questions", menu = questions5) #Names question menus
-	
-	tkadd(Ch5, "command", label = "Sampling distribution basics", 
-        command = substitute(samp.dist.mech(100))) # Ch 5 
+      tkadd(questions5, "command", label = "Sampling distributions", 
+      command = substitute(selftest.sampd.tck1())) # Ch 5 question
+      tkadd(questions5, "command", label = "Confidence intervals", 
+      command = substitute(selftest.conf.tck1())) # Ch 5 question
+  tkadd(Ch5, "command", label = "Confidence intervals", command = substitute(anm.ci.tck())) # Ch 5
+  tkadd(Ch5, "command", label = "MCMC simulation", command = substitute(anm.mc.bvn.tck())) # Ch 5
+  tkadd(Ch5, "command", label = "Sampling distribution basics", 
+        command = substitute(samp.dist.mech.tck())) # Ch 5 
 	tkadd(Ch5, "command", label = "Sampling distributions", 
         command = substitute(samp.dist.method.tck())) # Ch 5
-	tkadd(Ch5, "command", label = "Confidence intervals", command = substitute(anm.ci.tck())) # Ch 5
-	tkadd(Ch5, "command", label = "MCMC simulation", command = substitute(anm.mc.bvn.tck())) # Ch 5
-
-	tkadd(questions5, "command", label = "Sampling distributions", 
-        command = substitute(selftest.sampd.tck1())) # Ch 5 question
-	tkadd(questions5, "command", label = "Confidence intervals", 
-        command = substitute(selftest.conf.tck1())) # Ch 5 question
-	tkadd(topMenu, "cascade", label = "Chapter 5", menu = Ch5) # Names Ch 5
+  tkadd(topMenu, "cascade", label = "Chapter 5", menu = Ch5) # Names Ch 5
 	
 # Chapter 6
 
+  tkadd(Ch6, "cascade", label = "Self-test questions", menu = questions6) #Names question menus
 	tkadd(Ch6, "command", label = "Power", command = substitute(see.power.tck())) # Ch 6
 	tkadd(Ch6, "command", label = "t-test mechanics", command = substitute(see.ttest.tck())) # Ch 6
 	tkadd(Ch6, "command", label = "Type I and II error", command = substitute(see.typeI_II())) # Ch 6
@@ -89,10 +118,9 @@ book.menu <- function ()
 
 # Chapter 7
 
-	tkadd(questions7, "command", label = "Experimental and sampling design", 
-        command = substitute(selftest.se.tck1()))   # Ch 7 question
 	tkadd(Ch7, "cascade", label = "Self-test questions", menu = questions7) #Names question menus
-	
+	   tkadd(questions7, "command", label = "Experimental and sampling design", 
+     command = substitute(selftest.se.tck1()))   # Ch 7 question
 	tkadd(Ch7, "command", label = "Experimental designs", command = substitute(anm.ExpDesign.tck())) # Ch 7
 	tkadd(Ch7, "command", label = "Regression (Add/delete points)", 
         command = substitute(see.adddel())) # Ch 7 (also in Ch 9)
@@ -100,14 +128,17 @@ book.menu <- function ()
         command = substitute(see.move())) # Ch 7 (also in Ch 9)
 	tkadd(Ch7, "command", label = "Sampling designs", command = substitute(anm.samp.design.tck())) # Ch 7
 	tkadd(topMenu, "cascade", label = "Chapter 7", menu = Ch7) # Names Ch 7
+
 # Chapter 8
 
-	tkadd(Ch8, "command", label = "Effect of range on correlation", command = substitute(see.cor.range.tck())) # Ch 8
+	tkadd(Ch8, "cascade", label = "Self-test questions", menu = questions8) #Names question menus
+  tkadd(Ch8, "command", label = "Effect of range on correlation", command = substitute(see.cor.range.tck())) # Ch 8
 	tkadd(Ch8, "command", label = "Pearson correlation sampling distribution", command = substitute(see.r.dist.tck())) # Ch 8
 	tkadd(topMenu, "cascade", label = "Chapter 8", menu = Ch8) # Names Ch 7
 
 # Chapter 9
 
+  tkadd(Ch9, "cascade", label = "Self-test questions", menu = questions9) #Names question menus
 	tkadd(Ch9, "command", label = "Linear models (Regression)", 
         command = substitute(see.lmr.tck())) # Ch 9
 	tkadd(Ch9, "command", label = "Non-linear models", 
@@ -128,6 +159,7 @@ book.menu <- function ()
 	
 # Chapter 10
 
+  tkadd(Ch10, "cascade", label = "Self-test questions", menu = questions10) #Names question menus
 	tkadd(Ch10, "command", label = "ANOVA mechanics", 
         command = substitute(see.anova.tck())) # Ch 10
 	tkadd(Ch10, "command", label = "ANCOVA mechanics", 
@@ -144,6 +176,7 @@ book.menu <- function ()
 	
 # Chapter 11
 
+  tkadd(Ch11, "cascade", label = "Self-test questions", menu = questions11) #Names question menus
 	tkadd(Ch11, "command", label = "Multinomial distribution", 
         command = substitute(see.mnom.tck())) # Ch 11
 	tkadd(Ch11, "command", label = "Simpson's paradox", 
@@ -167,14 +200,5 @@ book.menu <- function ()
 	tkadd(Biology, "command", label = "Matrix population models", 
         command = substitute(anm.TM.tck()))       
 	tkadd(topMenu, "cascade", label = "Biology", menu = Biology)
-
-# Shaded Distributions
-
-    tkadd(dists1, "command", label = "Normal", command = substitute(shade.norm.tck()))  
-    tkadd(dists1, "command", label = "Binomial", command = substitute(shade.bin.tck()))
-    tkadd(dists1, "command", label = "Chi-square", command = substitute(shade.chi.tck()))
-    tkadd(dists1, "command", label = "F", command = substitute(shade.F.tck()))
-    tkadd(dists1, "command", label = "Poisson", command = substitute(shade.poi.tck()))
-    tkadd(dists1, "command", label = "t", command = substitute(shade.t.tck()))
 }
 
